@@ -15,7 +15,7 @@ class BaseHandler(tornado.web.RequestHandler):
         user_json = self.get_secure_cookie("user")
         if not user_json: 
             return None
-        return tornado.escape.json_decode(user_json)
+        return user_json
 
 class GradeNotebooks():
     async def grade(self, p, notebooks_zip):
